# Generated by Django 2.2.9 on 2020-02-04 11:08

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="TestKid",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("happy", models.BooleanField()),
                ("name", models.CharField(max_length=30)),
                ("age", models.IntegerField()),
                ("bio", models.TextField()),
                ("wanted_games_qtd", models.BigIntegerField()),
                ("birthday", models.DateField()),
                ("appointment", models.DateTimeField()),
            ],
        ),
    ]
