# Generated by Django 3.2.10 on 2022-01-04 08:48

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("demoproject", "0003_testkid_author"),
    ]

    operations = [
        migrations.AddField(
            model_name="testkid",
            name="height",
            field=models.IntegerField(null=True),
        ),
    ]
