# Generated by Django 3.1.5 on 2021-02-21 11:41

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("demoproject", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="testkid",
            name="appointment",
            field=models.DateTimeField(null=True),
        ),
        migrations.AlterField(
            model_name="testkid",
            name="birthday",
            field=models.DateField(null=True),
        ),
    ]
